==> ksystemlog-14.11.95.tar.xz: ksystemlog-14.11.95/src/lib/logModeFactory.h <==
/***************************************************************************
 *   KSystemLog, a system log viewer tool                                  *
 *   Copyright (C) 2007 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef _LOG_MODE_FACTORY_H_
#define _LOG_MODE_FACTORY_H_

#include <QObject>
#include <QList>

class LogModeAction;
class LogMode;

class LogModeFactory : public QObject {
	
	Q_OBJECT
	
	public:
		explicit LogModeFactory();
		
		virtual ~LogModeFactory();
		
		virtual LogModeAction* createLogModeAction() const = 0;

		/**
		 * Create the log mode
		 */
		virtual QList<LogMode*> createLogModes() const = 0;

};


#endif // _LOG_MODE_FACTORY_H_

==> ksystemlog-18.08.0.tar.xz: ksystemlog-18.08.0/src/lib/logModeFactory.h <==
/***************************************************************************
 *   KSystemLog, a system log viewer tool                                  *
 *   Copyright (C) 2007 by Nicolas Ternisien                               *
 *   nicolas.ternisien@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#ifndef _LOG_MODE_FACTORY_H_
#define _LOG_MODE_FACTORY_H_

#include <QObject>
#include <QList>

class LogModeAction;
class LogMode;

class LogModeFactory : public QObject
{
    Q_OBJECT

public:
    explicit LogModeFactory();

    virtual ~LogModeFactory();

    virtual LogModeAction *createLogModeAction() const = 0;

    /**
     * Create the log mode
     */
    virtual QList<LogMode *> createLogModes() const = 0;
};

#endif // _LOG_MODE_FACTORY_H_
